# Should major the configure.patch and the upstream LTS branch name.
%define major   20250127
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

%define desc \
Abseil is an open-source collection of C++ library code designed to augment \
the C++ standard library. The Abseil library code is collected from \
Google's own C++ code base, has been extensively tested and used in \
production, and is the same code we depend on in our daily coding lives. \
\
In some cases, Abseil provides pieces missing from the C++ standard; in \
others, Abseil provides alternatives to the standard for special needs we've \
found through usage in the Google code base. We denote those cases clearly \
within the library code we provide you. \
\
Abseil is not meant to be a competitor to the standard library; we've just \
found that many of these utilities serve a purpose within our code base, \
and we now want to provide those resources to the C++ community as a whole.

Name:           abseil-cpp
Version:        20250127.0
Release:        %mkrel 1
Summary:        Collection of C++ libraries augmenting the C++ standard library
Group:          Development/C++
License:        ASL 2.0
URL:            https://abseil.io
Source0:        https://github.com/abseil/abseil-cpp/archive/%{version}/%{name}-%{version}.tar.gz

# Originally from Debian, fixes SONAME and SSE2 on i386
# https://salsa.debian.org/debian/abseil/-/blob/master/debian/patches/configure.diff
# IMPORTANT: This patch has Mageia modification, don't update it without reviewing the diff.
Patch0:         abseil-cpp-configure.patch

BuildRequires:  cmake
BuildRequires:  ninja

%description
%{desc}

%package -n %{libname}
Summary:        Collection of C++ libraries augmenting the C++ standard library
Group:          System/Libraries

%description -n %{libname}
%{desc}

%package -n %{devname}
Summary:        Development files for the Abseil C++ libraries
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for the Abseil C++ libraries.

%prep
%autosetup -p1

%build
# libphonenumber >= 8.13 needs libabseil-cpp built with -DCMAKE_POSITION_INDEPENDENT_CODE=ON
%cmake -GNinja \
  -DCMAKE_CXX_STANDARD=17 \
  -DCMAKE_POSITION_INDEPENDENT_CODE=ON
%cmake_build

%install
%cmake_install

%files -n %{libname}
%license LICENSE
%doc FAQ.md README.md UPGRADES.md
%{_libdir}/libabsl_*.so.%{major}
%{_libdir}/libabsl_*.so.%{version}

%files -n %{devname}
%{_includedir}/absl/
%{_libdir}/cmake/absl/
%{_libdir}/libabsl_*.so
%{_libdir}/pkgconfig/absl_*.pc


%changelog
* Sat Mar 08 2025 wally <wally> 20250127.0-1.mga10
+ Revision: 2162065
- new version 20250127.0

* Sat May 25 2024 cjw <cjw> 20240116.2-1.mga10
+ Revision: 2067594
- new version 20240116.2
- change config to use C++17 standard versions of any, optional,
  string_view, and variant

* Wed Jan 17 2024 wally <wally> 20230802.1-1.mga10
+ Revision: 2031787
- new version 20230802.1
- build using Ninja

* Tue Sep 12 2023 wally <wally> 20230802.0-1.mga10
+ Revision: 1986368
- new version 20230802.0

* Tue Nov 22 2022 daviddavid <daviddavid> 20220623.1-4.mga9
+ Revision: 1910279
- compile with CMAKE_POSITION_INDEPENDENT_CODE=ON, needed for libphonenumber >= 8.13

* Fri Sep 09 2022 akien <akien> 20220623.1-3.mga9
+ Revision: 1886124
+ rebuild (emptylog)

* Fri Sep 09 2022 akien <akien> 20220623.1-2.mga9
+ Revision: 1886117
- Fixup major after previous commit, add needed Obsoletes

* Thu Sep 08 2022 neoclust <neoclust> 20220623.1-1.mga9
+ Revision: 1886036
- New version 20220623.1

* Mon Aug 08 2022 wally <wally> 20220623.0-1.mga9
+ Revision: 1876254
- new version 20220623.0
- new lib major 2206.0.0

* Thu Mar 17 2022 umeabot <umeabot> 20211102.0-2.mga9
+ Revision: 1796829
- Mageia 9 Mass Rebuild

* Tue Dec 28 2021 wally <wally> 20211102.0-1.mga9
+ Revision: 1765069
- new version 20211102.0
- new lib major 2111.0.0
- build using C++17 standard

* Fri Jan 01 2021 akien <akien> 20200923.2-1.mga8
+ Revision: 1668039
- Version 20200923.2

* Wed Oct 14 2020 akien <akien> 20200923.1-1.mga8
+ Revision: 1635906
- imported package abseil-cpp

